==> jbossas-plugin-1.3.2.1-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasUndeployApplicationStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;

/**
 * Undeploys a {@link com.xebialabs.deployit.ci.artifact.Ear} or a {@link com.xebialabs.deployit.ci.artifact.War} from a
 * {@link com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer}
 */
@SuppressWarnings("serial")
public class JbossasUndeployApplicationStep extends JbossasDeploymentStepBase {

	public JbossasUndeployApplicationStep(JbossasServer server, Ear ear) {
		super(server, ear);
		setDescription("Undeploy EAR " + ear + " from JBoss server " + server);
	}

	public JbossasUndeployApplicationStep(JbossasServer server, War war) {
		super(server, war);
		setDescription("Undeploy WAR " + war + " from JBoss server " + server);
	}

	public JbossasUndeployApplicationStep(JbossasServer server, EjbJar ejbJar) {
		super(server, ejbJar);
		setDescription("Undeploy EJB " + ejbJar + " from JBoss server " + server);
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession s = server.connectToAdminHost();
		try {
			String artifactTargetFileName = getArtifactTargetFileName();
			HostFile deployDir = s.getFile(server.getDeployDirPath());
			HostFile targetDeployFile = deployDir.getFile(artifactTargetFileName);
			ctx.logOutput("Removing application artifact from " + targetDeployFile.getPath() + " on " + server.getHost());
			targetDeployFile.delete();

			ctx.logOutput("Done.");
			return true;
		} finally {
			s.close();
		}
	}

}

==> jbossas-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasUndeployApplicationStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasEarMapping;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasEjbJarMapping;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasWarMapping;

/**
 * Undeploys a {@link com.xebialabs.deployit.ci.artifact.Ear} or a {@link com.xebialabs.deployit.ci.artifact.War} from a
 * {@link com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer}
 */
@SuppressWarnings("serial")
public class JbossasUndeployApplicationStep extends JbossasDeploymentStepBase {

	public JbossasUndeployApplicationStep(JbossasServer server, Ear ear, JbossasEarMapping mapping) {
		super(server, ear, mapping);
		setDescription("Undeploy EAR " + ear + " from JBoss server " + server);
	}

	public JbossasUndeployApplicationStep(JbossasServer server, War war, JbossasWarMapping mapping) {
		super(server, war, mapping);
		setDescription("Undeploy WAR " + war + " from JBoss server " + server);
	}

	public JbossasUndeployApplicationStep(JbossasServer server, EjbJar ejbJar, JbossasEjbJarMapping mapping) {
		super(server, ejbJar, mapping);
		setDescription("Undeploy EJB " + ejbJar + " from JBoss server " + server);
	}


	public boolean execute(StepExecutionContext ctx) {
		HostSession s = server.connectToAdminHost();
		try {
			String artifactTargetFileName = getArtifactTargetFileName();
			HostFile deployDir = s.getFile(server.getDeployDirPath());
			HostFile targetDeployFile = deployDir.getFile(artifactTargetFileName);
			ctx.logOutput("Removing application artifact from " + targetDeployFile.getPath() + " on " + server.getHost());
			targetDeployFile.delete();

			ctx.logOutput("Done.");
			return true;
		} finally {
			s.close();
		}
	}

}
